"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.matchChildAtRule = exports.matchAtRule = void 0;
const css_mediaquery_1 = require("css-mediaquery");
function matchAtRule({ rule, params, hover, active, focus, componentInteraction, platform, colorScheme, deviceMediaContext: { width, height, orientation }, }) {
    // eslint-disable-next-line unicorn/prefer-switch
    if (rule === "pseudo-class") {
        switch (params) {
            case "hover":
                return hover;
            case "focus":
                return focus;
            case "active":
                return active;
            default:
                return false;
        }
    }
    else if (rule === "component") {
        switch (params) {
            case "hover":
                return componentInteraction.hover;
            case "focus":
                return componentInteraction.focus;
            case "active":
                return componentInteraction.active;
            default:
                return false;
        }
    }
    else if (rule === "media" && params) {
        return (0, css_mediaquery_1.match)(params, {
            "aspect-ratio": width / height,
            "device-aspect-ratio": width / height,
            type: platform,
            width,
            height,
            "device-width": width,
            "device-height": width,
            orientation,
            "prefers-color-scheme": colorScheme,
        });
    }
    else if (rule === "dynamic-style") {
        return true;
    }
    return false;
}
exports.matchAtRule = matchAtRule;
function matchChildAtRule({ nthChild, rule, params, parentHover, parentFocus, parentActive, }) {
    if (rule === "selector" &&
        params === "(> *:not(:first-child))" &&
        nthChild > 1) {
        return true;
    }
    else if (rule === "selector" && params === "(> *)") {
        return true;
    }
    else if (rule === "component") {
        switch (params) {
            case "hover":
                return parentHover;
            case "focus":
                return parentFocus;
            case "active":
                return parentActive;
            default:
                return false;
        }
    }
    return false;
}
exports.matchChildAtRule = matchChildAtRule;
