"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.babelImport = exports.babelStyleSerializer = void 0;
const types_1 = require("@babel/types");
const serialize_styles_1 = require("./serialize-styles");
function babelStyleSerializer(styleRecord) {
    const { styles, media, ...rest } = (0, serialize_styles_1.serializeStyles)(styleRecord, babelReplacer);
    return {
        styles: babelSerializeObject(styles),
        media: babelSerializeObject(media),
        hasStyles: Object.keys(styles).length > 0,
        ...rest,
    };
}
exports.babelStyleSerializer = babelStyleSerializer;
function babelImport(name) {
    return `___tw_${name}`;
}
exports.babelImport = babelImport;
function babelReplacer(key, value) {
    if (typeof value !== "string") {
        return [key, value];
    }
    if (value === "styleSheet(hairlineWidth)") {
        return [
            key,
            (0, types_1.memberExpression)((0, types_1.identifier)("RNStyleSheet"), (0, types_1.identifier)("hairlineWidth")),
        ];
    }
    if (value.startsWith("platformColor(")) {
        const result = value.match(/platformColor\((.+)\)/);
        if (!result)
            return [key, (0, types_1.identifier)("undefined")];
        const variables = result[1]
            .split(/[ ,]+/)
            .filter(Boolean)
            .map((v) => (0, types_1.stringLiteral)(v));
        return [key, (0, types_1.callExpression)((0, types_1.identifier)("RNPlatformColor"), variables)];
    }
    if (value.startsWith("platform(")) {
        const result = value.match(/platform\((.+)\)/);
        if (!result)
            return [key, (0, types_1.identifier)("undefined")];
        const props = result[1]
            .trim()
            .split(/\s+/)
            .map((a) => {
            // Edge case:
            //   platform(android:platformColor(@android:color/holo_blue_bright))
            // Sometimes the value can has a colon, so we need to collect all values
            // and join them
            let [platform, ...values] = a.split(":");
            if (!values) {
                values = [platform];
                platform = "default";
            }
            const [key, value] = babelReplacer(platform, `${values.join("")}`);
            if (typeof value === "object" && (0, types_1.isExpression)(value)) {
                return (0, types_1.objectProperty)((0, types_1.identifier)(key), value);
            }
            else if (typeof value === "string") {
                return (0, types_1.objectProperty)((0, types_1.identifier)(key), (0, types_1.stringLiteral)(value));
            }
            else {
                throw new TypeError("Shouldn't reach here");
            }
        });
        return [
            key,
            (0, types_1.callExpression)((0, types_1.memberExpression)((0, types_1.identifier)("RNPlatform"), (0, types_1.identifier)("select")), [(0, types_1.objectExpression)(props)]),
        ];
    }
    return [key, value];
}
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function babelSerializeObject(literal) {
    if ((0, types_1.isExpression)(literal)) {
        return literal;
    }
    if (literal === null) {
        return (0, types_1.nullLiteral)();
    }
    switch (typeof literal) {
        case "number":
            return (0, types_1.numericLiteral)(literal);
        case "string":
            return (0, types_1.stringLiteral)(literal);
        case "boolean":
            return (0, types_1.booleanLiteral)(literal);
        case "undefined":
            return (0, types_1.unaryExpression)("void", (0, types_1.numericLiteral)(0), true);
        default:
            if (Array.isArray(literal)) {
                return (0, types_1.arrayExpression)(literal.map((n) => babelSerializeObject(n)));
            }
            if (isObject(literal)) {
                return (0, types_1.objectExpression)(Object.keys(literal)
                    .filter((k) => {
                    return typeof literal[k] !== "undefined";
                })
                    .map((k) => {
                    return (0, types_1.objectProperty)((0, types_1.stringLiteral)(k), babelSerializeObject(literal[k]));
                }));
            }
            throw new Error("un-serializable literal");
    }
}
function isObject(literal) {
    return typeof literal === "object";
}
